==> haskell-hasql-implicits-0.1.0.5-132-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-implicits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-3ntSl15XuVyATu9fySK9qe
key:                  hasql-implicits-0.1.0.5-3ntSl15XuVyATu9fySK9qe
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  adde3b7a61a6b23848dc4160aac9ea3b
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-3ntSl15XuVyATu9fySK9qe
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    hasql-1.5.0.4-3X2mZlxdWL044URuQ7OkF4
    network-ip-0.3.0.3-aTc0sbAH1GG00pTkUt0LL
    scientific-0.3.7.0-DmJatUkkzP1HryFyYrhDfx text-1.2.5.0
    time-1.11.1.1 uuid-1.3.15-5G75epcUDQqCLu4om96pvk
    vector-0.13.1.0-HyaXkpW7aOFHhHqdwTfvZq

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-implicits-0.1.0.5-145-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-implicits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-A567VS4KtbzBSEEtSvy8a8
key:                  hasql-implicits-0.1.0.5-A567VS4KtbzBSEEtSvy8a8
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  2cdb76949091ba4e46e5952e60ae3377
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-A567VS4KtbzBSEEtSvy8a8
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    hasql-1.5.0.4-6GDwBu1ouGLL97aqfLNtDJ
    network-ip-0.3.0.3-907CXyG3Kh7L4lUZXKJzlG
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD text-1.2.5.0 time-1.11.1.1
    uuid-1.3.15-7dlZ5e7FtKwKVMt3dzHFPs
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
